# file: listCerts.pl

use chilkat;

# List digital certificates in the Windows registry stores:
# List the certs in the Current User Store,
# then list the certs in the Local Machine Certificate Store.

# The CkCert, CkCertStore, and CkCreateCS are free utility classes that can be 
# used in any Perl application/script without the need to purchase a license.

$ccs = new chilkat::CkCreateCS();

# Open the current-user certificate store in read-only mode.
$ccs->put_ReadOnly(true);
$certStore = $ccs->OpenCurrentUserStore();

if ($certStore == null)
{
	$ccs->SaveLastError("lastError.txt");
	print "Failed to open current user certificate store\n";
}
else
{
	print "Current User Digital Certificates:\n";
	$n = $certStore->get_NumCertificates();
	for ($i = 0; $i < $n; $i++)
		{
		$cert = $certStore->GetCertificate($i);
		# Print the common name of the certificate.
		print "CN: " . $cert->subjectCN . "\n";
		}
}
print "\n";

# Open the local-machine certificate store in read-only mode.
$certStore = $ccs->OpenLocalSystemStore();

if ($certStore == null)
{
	$ccs->SaveLastError("lastError.txt");
	print "Failed to open current user certificate store\n";
}
else
{
	print "Local Machine Digital Certificates:\n";
	$n = $certStore->get_NumCertificates();
	for ($i = 0; $i < $n; $i++)
		{
		$cert = $certStore->GetCertificate($i);
		# Print the common name of the certificate.
		print "CN: " . $cert->subjectCN . "\n";
		}
}

